OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nie można zapisać do katalogu \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Zwykle można to naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu config.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ale jeśli wolisz, aby plik config.php był tylko do odczytu, ustaw w nim opcję \"config_is_read_only\" na true.",
    "See %s" : "Zobacz %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Aplikacja %1$s nie jest dostępna lub ma wersję niekompatybilną z tym serwerem. Sprawdź katalog aplikacji.",
    "Sample configuration detected" : "Wykryto przykładową konfigurację",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Wykryto, że przykładowa konfiguracja została skopiowana. Może to spowodować przerwanie instalacji, która nie jest wspierana. Przeczytaj dokumentację przed dokonaniem zmian w pliku config.php",
    "The page could not be found on the server." : "Nie znaleziono strony na serwerze.",
    "%s email verification" : "Weryfikacja adresu e-mail %s",
    "Email verification" : "Weryfikacja adresu e-mail",
    "Click the following button to confirm your email." : "Kliknij poniższy przycisk, aby potwierdzić swój adres e-mail.",
    "Click the following link to confirm your email." : "Kliknij poniższy link, aby potwierdzić swój adres e-mail.",
    "Confirm your email" : "Potwierdź swój adres e-mail",
    "Other activities" : "Inne aktywności",
    "%1$s and %2$s" : "%1$s i %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s i %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s i %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s i %5$s",
    "Education Edition" : "Edycja edukacyjna",
    "Enterprise bundle" : "Pakiet dla firm",
    "Groupware bundle" : "Pakiet do pracy grupowej",
    "Hub bundle" : "Pakiet centralny",
    "Social sharing bundle" : "Pakiet udostępniania społecznościowego",
    "PHP %s or higher is required." : "Wymagane jest PHP %s lub wyższe.",
    "PHP with a version lower than %s is required." : "Wymagane jest PHP z wersją niższą niż %s.",
    "%sbit or higher PHP required." : "%sbit lub wymagane wyższe PHP.",
    "The following architectures are supported: %s" : "Obsługiwane są następujące architektury: %s",
    "The following databases are supported: %s" : "Obsługiwane są następujące bazy danych: %s",
    "The command line tool %s could not be found" : "Nie można znaleźć narzędzia wiersza poleceń %s",
    "The library %s is not available." : "Biblioteka %s nie jest dostępna.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Wymagana jest biblioteka %1$s z wersją wyższą niż %2$s - dostępna wersja %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Wymagana jest biblioteka %1$s w wersji niższej niż %2$s - dostępna wersja %3$s.",
    "The following platforms are supported: %s" : "Obsługiwane są następujące platformy: %s",
    "Server version %s or higher is required." : "Wymagana jest wersja serwera %s lub wyższa.",
    "Server version %s or lower is required." : "Wymagana jest wersja serwera %s lub niższa.",
    "Wiping of device %s has started" : "Rozpoczęto czyszczenie urządzenia %s",
    "Wiping of device »%s« has started" : "Rozpoczęto czyszczenie urządzenia »%s«",
    "»%s« started remote wipe" : "»%s« rozpoczęło zdalne czyszczenie",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Urządzenie lub aplikacja »%s« uruchomiło proces zdalnego czyszczenia. Otrzymasz kolejny e-mail po zakończeniu procesu",
    "Wiping of device %s has finished" : "Zakończono czyszczenie urządzenia %s",
    "Wiping of device »%s« has finished" : "Zakończono czyszczenie urządzenia »%s«",
    "»%s« finished remote wipe" : "»%s« zakończył zdalne czyszczenie",
    "Device or application »%s« has finished the remote wipe process." : "Urządzenie lub aplikacja »%s« zakończyło proces zdalnego czyszczenia.",
    "Remote wipe started" : "Rozpoczęto zdalne czyszczenie",
    "A remote wipe was started on device %s" : "Zdalne czyszczenie zostało uruchomione na urządzeniu %s",
    "Remote wipe finished" : "Zdalne czyszczenie zakończone",
    "The remote wipe on %s has finished" : "Zakończono zdalne czyszczenie na %s",
    "Authentication" : "Uwierzytelnienie",
    "Unknown filetype" : "Nieznany typ pliku",
    "Invalid image" : "Nieprawidłowy obraz",
    "Avatar image is not square" : "Obraz awatara nie jest kwadratowy",
    "Files" : "Pliki",
    "View profile" : "Zobacz profil",
    "Local time: %s" : "Czas lokalny: %s",
    "today" : "dzisiaj",
    "tomorrow" : "jutro",
    "yesterday" : "wczoraj",
    "_in %n day_::_in %n days_" : ["za %n dzień","za %n dni","za %n dni","za %n dni"],
    "_%n day ago_::_%n days ago_" : ["%n dzień temu","%n dni temu","%n dni temu","%n dni temu"],
    "next month" : "następny miesiąc",
    "last month" : "w zeszłym miesiącu",
    "_in %n month_::_in %n months_" : ["za %n miesiąc","za %n miesiące","za %n miesięcy","za %n miesięcy"],
    "_%n month ago_::_%n months ago_" : ["%n miesiąc temu","%n miesiące temu","%n miesięcy temu","%n miesięcy temu"],
    "next year" : "następny rok",
    "last year" : "w zeszłym roku",
    "_in %n year_::_in %n years_" : ["za %n rok","za %n lata","za %n lat","za %n lat"],
    "_%n year ago_::_%n years ago_" : ["%n rok temu","%n lata temu","%n lat temu","%n lat temu"],
    "_in %n hour_::_in %n hours_" : ["za %n godzinę","za %n godziny","za %n godzin","za %n godzin"],
    "_%n hour ago_::_%n hours ago_" : ["%n godzina temu","%n godziny temu","%n godzin temu","%n godzin temu"],
    "_in %n minute_::_in %n minutes_" : ["za %n minutę","za %n minuty","za %n minut","za %n minut"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuta temu","%n minuty temu","%n minut temu","%n minut temu"],
    "in a few seconds" : "za kilka sekund",
    "seconds ago" : "przed chwilą",
    "Empty file" : "Pusty plik",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Moduł o ID: %s nie istnieje. Włącz go w ustawieniach aplikacji lub skontaktuj się z administratorem.",
    "File already exists" : "Plik już istnieje",
    "Invalid path" : "Niewłaściwa ścieżka",
    "Failed to create file from template" : "Nie udało się utworzyć pliku z szablonu",
    "Templates" : "Szablony",
    "File name is a reserved word" : "Nazwa pliku jest zarezerwowana",
    "File name contains at least one invalid character" : "Nazwa pliku zawiera co najmniej jeden nieprawidłowy znak",
    "File name is too long" : "Nazwa pliku jest za długa",
    "Dot files are not allowed" : "Pliki z kropką są nie dozwolone",
    "Empty filename is not allowed" : "Pusta nazwa pliku jest niedozwolona",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikacji \"%s\" nie można zainstalować, ponieważ nie można odczytać pliku appinfo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikacji \"%s\" nie można zainstalować, ponieważ nie jest kompatybilna z tą wersją serwera.",
    "__language_name__" : "Polski",
    "This is an automatically sent email, please do not reply." : "Jest to wiadomość e-mail wysłana automatycznie, prosimy nie odpowiadać na nią.",
    "Help" : "Pomoc",
    "Appearance and accessibility" : "Wygląd i dostępność",
    "Apps" : "Aplikacje",
    "Personal settings" : "Ustawienia osobiste",
    "Administration settings" : "Ustawienia administracyjne",
    "Settings" : "Ustawienia",
    "Log out" : "Wyloguj",
    "Users" : "Użytkownicy",
    "Email" : "E-mail",
    "Mail %s" : "Poczta %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Zobacz %s w Fediverse",
    "Phone" : "Telefon",
    "Call %s" : "Połącz %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Zobacz %s na Twitterze",
    "Website" : "Strona internetowa",
    "Visit %s" : "Odwiedź %s",
    "Address" : "Adres",
    "Profile picture" : "Zdjęcie profilowe",
    "About" : "Informacje",
    "Display name" : "Wyświetlana nazwa",
    "Headline" : "Nagłówek",
    "Organisation" : "Organizacja",
    "Role" : "Rola społeczna",
    "Additional settings" : "Ustawienia dodatkowe",
    "Enter the database name for %s" : "Podaj nazwę bazy danych dla %s",
    "You cannot use dots in the database name %s" : "Nie można używać kropek w nazwie bazy danych %s",
    "You need to enter details of an existing account." : "Musisz wprowadzić szczegółowe dane dla istniejącego konta.",
    "Oracle connection could not be established" : "Nie można nawiązać połączenia z bazą danych Oracle",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nie jest wspierany i %s nie będzie działać poprawnie na tej platformie. Używasz go na własne ryzyko!",
    "For the best results, please consider using a GNU/Linux server instead." : "Aby uzyskać najlepszy efekt, rozważ użycie serwera GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Wydaje się, że ta instancja %s używa PHP dla 32-bitowego środowiska, ponieważ open_basedir został tak skonfigurowany w php.ini. Doprowadzi to do problemów z plikami powyżej 4 GB i jest bardzo niezalecane.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Usuń ustawienie open_basedir w php.ini lub przełącz na PHP 64-bitowe.",
    "Set an admin password." : "Ustaw hasło administratora.",
    "Cannot create or write into the data directory %s" : "Nie można tworzyć ani zapisywać w katalogu %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Zaplecze do udostępniania %s musi implementować interfejs OCP\\Share_Backend",
    "Sharing backend %s not found" : "Zaplecze %s do udostępniania nie zostało znalezione",
    "Sharing backend for %s not found" : "Zaplecze do udostępniania dla %s nie zostało znalezione",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s udostępnił Tobie »%2$s« i chce dodać: ",
    "%1$s shared »%2$s« with you and wants to add" : " %1$s udostępnił Tobie »%2$s« i chce dodać",
    "»%s« added a note to a file shared with you" : "»%s« dodał notatkę do udostępnionego dla Ciebie pliku",
    "Open »%s«" : "Otwórz »%s«",
    "%1$s via %2$s" : "%1$s przez %2$s",
    "You are not allowed to share %s" : "Nie możesz udostępnić %s",
    "Cannot increase permissions of %s" : "Nie można zwiększyć uprawnień %s",
    "Files cannot be shared with delete permissions" : "Pliki nie mogą zostać udostępnione z prawem do usuwania",
    "Files cannot be shared with create permissions" : "Pliki nie mogą zostać udostępnione z prawem do tworzenia",
    "Expiration date is in the past" : "Data ważności już minęła",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nie można utworzyć daty wygaśnięcia na %n dzień do przodu","Nie można utworzyć daty wygaśnięcia na %n dni do przodu","Nie można utworzyć daty wygaśnięcia na %n dni do przodu","Nie można utworzyć daty wygaśnięcia na %n dni do przodu"],
    "Sharing is only allowed with group members" : "Udostępnianie jest dozwolone tylko członkom grupy",
    "%1$s shared »%2$s« with you" : "%1$s udostępnił Tobie »%2$s«",
    "%1$s shared »%2$s« with you." : "%1$s udostępnił Tobie »%2$s«.",
    "Click the button below to open it." : "Kliknij przycisk poniżej, aby otworzyć.",
    "The requested share does not exist anymore" : "Żądane udostępnienie już nie istnieje",
    "The requested share comes from a disabled user" : "Żądane udostępnienie pochodzi od wyłączonego użytkownika",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Użytkownik nie został utworzony, ponieważ osiągnięto limit użytkowników. Sprawdź swoje powiadomienia, aby dowiedzieć się więcej.",
    "Could not find category \"%s\"" : "Nie można znaleźć kategorii \"%s\"",
    "Sunday" : "Niedziela",
    "Monday" : "Poniedziałek",
    "Tuesday" : "Wtorek",
    "Wednesday" : "Środa",
    "Thursday" : "Czwartek",
    "Friday" : "Piątek",
    "Saturday" : "Sobota",
    "Sun." : "Nd.",
    "Mon." : "Pon.",
    "Tue." : "Wt.",
    "Wed." : "Śr.",
    "Thu." : "Czw.",
    "Fri." : "Pt.",
    "Sat." : "Sob.",
    "Su" : "Nd",
    "Mo" : "Pn",
    "Tu" : "Wt",
    "We" : "Śr",
    "Th" : "Czw",
    "Fr" : "Pt",
    "Sa" : "Sob",
    "January" : "Styczeń",
    "February" : "Luty",
    "March" : "Marzec",
    "April" : "Kwiecień",
    "May" : "Maj",
    "June" : "Czerwiec",
    "July" : "Lipiec",
    "August" : "Sierpień",
    "September" : "Wrzesień",
    "October" : "Październik",
    "November" : "Listopad",
    "December" : "Grudzień",
    "Jan." : "Sty.",
    "Feb." : "Lut.",
    "Mar." : "Mar.",
    "Apr." : "Kwi.",
    "May." : "Maj",
    "Jun." : "Cze.",
    "Jul." : "Lip.",
    "Aug." : "Sie.",
    "Sep." : "Wrz.",
    "Oct." : "Paź.",
    "Nov." : "Lis.",
    "Dec." : "Gru.",
    "A valid password must be provided" : "Należy podać prawidłowe hasło",
    "Login canceled by app" : "Logowanie anulowane przez aplikację",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Nie można zainstalować aplikacji \"%1$s\", ponieważ nie są spełnione następujące zależności: %2$s",
    "a safe home for all your data" : "bezpieczny dom dla wszystkich Twoich danych",
    "File is currently busy, please try again later" : "Plik jest obecnie niedostępny, spróbuj później",
    "Cannot download file" : "Nie można pobrać pliku",
    "Application is not enabled" : "Aplikacja nie jest włączona",
    "Authentication error" : "Błąd uwierzytelniania",
    "Token expired. Please reload page." : "Token wygasł. Przeładuj stronę.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nie zainstalowano sterowników bazy danych (sqlite, mysql lub postgresql).",
    "Cannot write into \"config\" directory." : "Nie można zapisać do katalogu \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Zwykle można to naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu config. Zobacz %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Jeśli, albo wolisz zachować plik config.php tylko do odczytu, ustaw w nim opcję \"config_is_read_only\" na true. Zobacz %s",
    "Cannot write into \"apps\" directory." : "Nie można zapisać do katalogu \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Zwykle można to naprawić, przyznając serwerowi WWW dostęp do zapisu do katalogu aplikacji lub wyłączając Nextcloud App Store w pliku konfiguracyjnym.",
    "Cannot create \"data\" directory." : "Nie można utworzyć katalogu \"data\".",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Zwykle można to naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu głównego. Zobacz %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Uprawnienia można zazwyczaj naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu głównego. Zobacz %s.",
    "Your data directory is not writable." : "Katalog danych nie jest zapisywalny.",
    "Setting locale to %s failed." : "Ustawienie języka na %s nie powiodło się.",
    "Please install one of these locales on your system and restart your web server." : "Zainstaluj jedną z lokalizacji w swoim systemie i ponownie uruchom serwer WWW.",
    "PHP module %s not installed." : "Moduł PHP %s nie jest zainstalowany.",
    "Please ask your server administrator to install the module." : "Poproś administratora serwera o zainstalowanie modułu.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Ustawienie PHP \"%s\" nie jest ustawione na \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Dostosowanie tego ustawienia w php.ini spowoduje ponowne uruchomienie Nextcloud",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> jest ustawione na <code>%s</code> zamiast spodziewanej wartości <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Aby rozwiązać ten problem, ustaw <code>mbstring.func_overload</code> na <code>0</code> w pliku php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Wygląda na to, że PHP jest tak ustawione, aby wycinać bloki wklejonych dokumentów. Może to spowodować, że niektóre wbudowane aplikacje będą niedostępne.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Jest to prawdopodobnie spowodowane przez cache lub akcelerator, taki jak Zend OPcache lub eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Moduły PHP zostały zainstalowane, ale nadal brakuje ich na liście?",
    "Please ask your server administrator to restart the web server." : "Poproś administratora serwera o ponowne uruchomienie serwera WWW.",
    "The required %s config variable is not configured in the config.php file." : "Wymagana zmienna konfiguracyjna %s nie jest skonfigurowana w pliku config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Poproś administratora serwera o sprawdzenie konfiguracji Nextcloud.",
    "Your data directory must be an absolute path." : "Katalog danych musi mieć ścieżkę absolutną.",
    "Check the value of \"datadirectory\" in your configuration." : "Sprawdź wartość \"datadirectory\" w swojej konfiguracji.",
    "Your data directory is invalid." : "Katalog danych jest nieprawidłowy.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Upewnij się, że w katalogu \"data\" znajduje się plik o nazwie \".ocdata\".",
    "Action \"%s\" not supported or implemented." : "Akcja \"%s\" jest niewspierana lub niezaimplementowana.",
    "Authentication failed, wrong token or provider ID given" : "Uwierzytelnienie nie powiodło się, podano nieprawidłowy token lub ID dostawcy",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Brak parametrów w celu uzupełnienia żądania. Brakujące parametry: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" jest już używany przez dostawcę chmury federacyjnej \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Dostawca Chmury Federacyjnej o ID: \"%s\" nie istnieje.",
    "Could not obtain lock type %d on \"%s\"." : "Nie można uzyskać blokady typu %d na \"%s\".",
    "Storage unauthorized. %s" : "Magazyn nieautoryzowany. %s",
    "Storage incomplete configuration. %s" : "Niekompletna konfiguracja magazynu. %s",
    "Storage connection error. %s" : "Błąd połączenia z magazynem. %s",
    "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
    "Storage connection timeout. %s" : "Limit czasu połączenia do magazynu. %s",
    "Free prompt" : "Monit bezpłatny",
    "Runs an arbitrary prompt through the language model." : "Uruchamia dowolny monit w modelu języka.",
    "Generate headline" : "Wygeneruj nagłówek",
    "Generates a possible headline for a text." : "Generuje możliwy nagłówek tekstu.",
    "Summarize" : "Podsumuj",
    "Summarizes text by reducing its length without losing key information." : "Podsumowuje tekst, zmniejszając jego długość bez utraty kluczowych informacji.",
    "Extract topics" : "Wyodrębnij tematy",
    "Extracts topics from a text and outputs them separated by commas." : "Wyodrębnia tematy z tekstu i wyświetla je oddzielone przecinkami.",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Pliki aplikacji %1$s nie zostały poprawnie zastąpione. Upewnij się, że jest to wersja zgodna z serwerem.",
    "404" : "404",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Zalogowany użytkownik musi być administratorem, subadministratorem lub mieć specjalne uprawnienia dostępu do tego ustawienia",
    "Logged in user must be an admin or sub admin" : "Zalogowany użytkownik musi być administratorem lub współadministratorem",
    "Logged in user must be an admin" : "Zalogowany użytkownik musi być administratorem",
    "Full name" : "Pełna nazwa",
    "Unknown user" : "Nieznany użytkownik",
    "Enter the database username and name for %s" : "Podaj nazwę użytkownika i nazwę bazy danych dla %s",
    "Enter the database username for %s" : "Podaj nazwę użytkownika bazy danych dla %s",
    "MySQL username and/or password not valid" : "Błędna nazwa użytkownika i/lub hasło do bazy danych MySQL",
    "Oracle username and/or password not valid" : "Zła nazwa użytkownika i/lub hasło do bazy danych Oracle",
    "PostgreSQL username and/or password not valid" : "Zła nazwa użytkownika i/lub hasło do bazy danych PostgreSQL",
    "Set an admin username." : "Ustaw nazwę administratora.",
    "Sharing %s failed, because this item is already shared with user %s" : "Udostępnianie %s nie powiodło się, ponieważ element jest już udostępniony użytkownikowi %s",
    "The username is already being used" : "Ta nazwa użytkownika jest już używana",
    "Could not create user" : "Nie można utworzyć użytkownika",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "W nazwie użytkownika dozwolone są tylko następujące znaki : \"a-z\", \"A-Z\", \"0-9\", spacje i \"_.@-'\"",
    "A valid username must be provided" : "Należy podać prawidłową nazwę użytkownika",
    "Username contains whitespace at the beginning or at the end" : "Nazwa użytkownika zawiera spację na początku albo na końcu",
    "Username must not consist of dots only" : "Nazwa użytkownika nie może się składać tylko z kropek",
    "Username is invalid because files already exist for this user" : "Nazwa użytkownika jest nieprawidłowa, ponieważ pliki już istnieją dla tego użytkownika",
    "User disabled" : "Użytkownik zablokowany",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Wymagana wersja dla libxml2 to przynajmniej 2.7.0. Aktualnie zainstalowana jest %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Aby rozwiązać ten problem, zaktualizuj wersję libxml2 i ponownie uruchom serwer WWW.",
    "PostgreSQL >= 9 required." : "Wymagany PostgreSQL >= 9",
    "Please upgrade your database version." : "Zaktualizuj wersję bazy danych.",
    "Your data directory is readable by other users." : "Twój katalog danych jest widoczny dla innych użytkowników.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Zmień uprawnienia na 0770, aby katalog nie był widoczny dla innych użytkowników."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
